@@ -7,19 +7,22 @@ import os
 class CameraLogService:
     def __init__(self, camera_id):
         self.logger = logging.getLogger(os.getenv('LOGSTASH_NAME'))
+        self.logger.setLevel(int(os.getenv('LOGSTASH_LEVEL')))
 
         use_logtash = os.getenv('USE_LOGSTASH')
+        self.camera_id = camera_id
 
         if use_logtash == 'True':
             if self.logger.hasHandlers():
                 self.logger.handlers.clear()
 
-            self.logger.setLevel(logging.INFO)
             self.logger.addHandler(logstash.TCPLogstashHandler(os.getenv('LOGSTASH_HOST'), os.getenv('LOGSTASH_PORT'), version=1))
-            self.camera_id = camera_id
+            
             self.extra = {
                 'camera_id': self.camera_id,
             }
+        else:
+            self.extra = None
 
     def i(self, msg, *args):
         self.logger.info(msg, extra=self.extra)
