@@ -1,2 +1,5 @@
+import logging
+logging.basicConfig()
+
 from .LogService import log_service, LogService
 from .CameraLogService import CameraLogService, CameraLogServiceManager
\ No newline at end of file
